<?php

declare(strict_types = 1);

namespace Drupal\rokka;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Rokka\Client\Image;
use Rokka\Client\User;

/**
 * Rokka service interface.
 */
interface RokkaServiceInterface {

  /**
   * Return the given setting from the Rokka module configuration.
   *
   * Examples:
   * - source_image_style (default: , 'rokka_source')
   * - use_hash_as_name (default: true)
   *
   * @param string $param
   *   Parameter.
   *
   * @return mixed
   *   Settings.
   */
  public function getSettings($param);

  /**
   * Get the Rokka image client.
   *
   * @return \Rokka\Client\Image
   *   Client.
   */
  public function getRokkaImageClient(): Image;

  /**
   * Get the Rokka user client.
   *
   * @return \Rokka\Client\User
   *   User.
   */
  public function getRokkaUserClient(): User;

  /**
   * Get an image, given the URI.
   *
   * @param string $uri
   *   URI.
   *
   * @return \Drupal\rokka\Entity\RokkaMetadata[]
   *   Entities.
   */
  public function loadRokkaMetadataByUri($uri): array;

  /**
   * Counts the number of images that share the same Hash.
   *
   * @param string $hash
   *   Hash.
   *
   * @return int
   *   Count.
   */
  public function countImagesWithHash($hash): int;

  /**
   * Get the entity type manager.
   *
   * Can probably be removed.
   *
   * @return \Drupal\Core\Entity\EntityTypeManagerInterface
   *   Entity type manager.
   */
  public function getEntityTypeManager(): EntityTypeManagerInterface;

  /**
   * Returns the organization name.
   *
   * @return mixed
   *   Organization name.
   */
  public function getRokkaOrganizationName();

}
