<?php

namespace Drupal\rokka;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\File\FileSystem;
use Drupal\Core\State\State;

/**
 * Class RokkaThumbnailManager.
 *
 * @package Drupal\rokka
 */
class RokkaThumbnailManager {

  /**
   * EntityTypeManager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * FileSystem.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * Configfactory.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * State.
   *
   * @var \Drupal\Core\State\State
   */
  protected $state;

  /**
   * RokkaThumbnailManager constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManager $entityTypeManager
   * @param \Drupal\Core\File\FileSystem $fileSystem
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   * @param \Drupal\Core\State\State $state
   */
  public function __construct(EntityTypeManager $entityTypeManager, FileSystem $fileSystem, ConfigFactory $configFactory, State $state) {
    $this->entityTypeManager = $entityTypeManager;
    $this->fileSystem = $fileSystem;
    $this->configFactory = $configFactory;
    $this->state = $state;
  }

  /**
   * Create pdf thumbnail.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *
   */
  public function createThumbnail(EntityInterface $entity) {
    $entityTypeId = $entity->getEntityTypeId();
    $bundle = $entity->bundle();
    if ($entityTypeId == 'media') {
      $config = $this->configFactory->get('rokka.bundles.settings');

      // If not enabled for this bundle.
      if (empty($config->get($bundle . '_enable'))) {
        return;
      }

      $fieldName = $config->get($bundle . '_field');
      if ($fieldName && $entity->hasField($fieldName) && !empty($entity->get($fieldName)->getValue())) {
        $fid = $entity->get($fieldName)->getValue()[0]['target_id'];
        /** @var \Drupal\file\FileInterface $fileEntity */
        $fileEntity = $this->entityTypeManager->getStorage('file')->load($fid);
        if ($fileEntity) {
          $entity->set(
            'thumbnail',
            [
              'target_id' => $fileEntity->id(),
              'alt' => $fileEntity->getFilename(),
            ]
          );
        }
      }
      return;
    }
  }

}
